@@ -1042,3 +1042,44 @@ class Proxy(proxy2.BaseProxy):
         :returns: A generator of event instances.
         """
         return self._list(_event.Event, paginated=True, **query)
+
+    def wait_for_status(self, resource, status, failures=[], interval=2,
+                        wait=120):
+        """Wait for a resource to be in a particular status.
+
+        :param resource: The resource to wait on to reach the specified status.
+                         The resource must have a ``status`` attribute.
+        :type resource: A :class:`~openstack.resource2.Resource` object.
+        :param status: Desired status.
+        :param failures: Statuses that would be interpreted as failures.
+        :type failures: :py:class:`list`
+        :param interval: Number of seconds to wait before to consecutive
+                         checks. Default to 2.
+        :param wait: Maximum number of seconds to wait before the change.
+                     Default to 120.
+        :returns: The resource is returned on success.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
+                 to the desired status failed to occur in specified seconds.
+        :raises: :class:`~openstack.exceptions.ResourceFailure` if the resource
+                 has transited to one of the failure statuses.
+        :raises: :class:`~AttributeError` if the resource does not have a
+                ``status`` attribute.
+        """
+        return resource2.wait_for_status(self._session, resource, status,
+                                         failures, interval, wait)
+
+    def wait_for_delete(self, resource, interval=2, wait=120):
+        """Wait for a resource to be deleted.
+
+        :param resource: The resource to wait on to be deleted.
+        :type resource: A :class:`~openstack.resource2.Resource` object.
+        :param interval: Number of seconds to wait before to consecutive
+                         checks. Default to 2.
+        :param wait: Maximum number of seconds to wait before the change.
+                     Default to 120.
+        :returns: The resource is returned on success.
+        :raises: :class:`~openstack.exceptions.ResourceTimeout` if transition
+                 to delete failed to occur in the specified seconds.
+        """
+        return resource2.wait_for_delete(self._session, resource, interval,
+                                         wait)
