@@ -22,6 +22,7 @@ from openstack.compute.v2 import server_group as _server_group
 from openstack.compute.v2 import server_interface as _server_interface
 from openstack.compute.v2 import server_ip
 from openstack.compute.v2 import service as _service
+from openstack.compute.v2 import volume_attachment as _volume_attachment
 from openstack import proxy2
 from openstack import resource2
 
@@ -197,7 +198,7 @@ class Proxy(proxy2.BaseProxy):
         :rtype: :class:`~openstack.compute.v2.image.Image`
         """
         res = self._get_base_resource(image, _image.Image)
-        metadata = res.get_metadata(self.session)
+        metadata = res.get_metadata(self._session)
         result = _image.Image.existing(id=res.id, metadata=metadata)
         return result
 
@@ -218,7 +219,7 @@ class Proxy(proxy2.BaseProxy):
         :rtype: :class:`~openstack.compute.v2.image.Image`
         """
         res = self._get_base_resource(image, _image.Image)
-        metadata = res.set_metadata(self.session, **metadata)
+        metadata = res.set_metadata(self._session, **metadata)
         result = _image.Image.existing(id=res.id, metadata=metadata)
         return result
 
@@ -231,12 +232,12 @@ class Proxy(proxy2.BaseProxy):
                        :class:`~openstack.compute.v2.image.Image` or
                        :class:`~openstack.compute.v2.image.ImageDetail`
                        instance.
-        :param list keys: The keys to delete.
+        :param keys: The keys to delete.
 
         :rtype: ``None``
         """
         res = self._get_base_resource(image, _image.Image)
-        return res.delete_metadata(self.session, keys)
+        return res.delete_metadata(self._session, keys)
 
     def create_keypair(self, **attrs):
         """Create a new keypair from attributes
@@ -340,7 +341,7 @@ class Proxy(proxy2.BaseProxy):
         """
         if force:
             server = self._get_resource(_server.Server, server)
-            server.force_delete(self.session)
+            server.force_delete(self._session)
         else:
             self._delete(_server.Server, server, ignore_missing=ignore_missing)
 
@@ -433,7 +434,20 @@ class Proxy(proxy2.BaseProxy):
         :returns: None
         """
         server = self._get_resource(_server.Server, server)
-        server.change_password(self.session, new_password)
+        server.change_password(self._session, new_password)
+
+    def reset_server_state(self, server, state):
+        """Reset the state of server
+
+        :param server: The server can be either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`.
+        :param state: The state of the server to be set, `active` or
+                      `error` are valid.
+
+        :returns: None
+        """
+        res = self._get_base_resource(server, _server.Server)
+        res.reset_state(self._session, state)
 
     def reboot_server(self, server, reboot_type):
         """Reboot a server
@@ -446,7 +460,7 @@ class Proxy(proxy2.BaseProxy):
         :returns: None
         """
         server = self._get_resource(_server.Server, server)
-        server.reboot(self.session, reboot_type)
+        server.reboot(self._session, reboot_type)
 
     def rebuild_server(self, server, name, admin_password, **attrs):
         """Rebuild a server
@@ -465,16 +479,16 @@ class Proxy(proxy2.BaseProxy):
                                 *Default: None*
         :param dict metadata: A dictionary of metadata to rebuild with.
                                *Default: None*
-        :param list personality: A list of dictionaries, each including a
-                                 **path** and **contents** key, to be injected
-                                 into the rebuilt server at launch.
-                                 *Default: None*
+        :param personality: A list of dictionaries, each including a
+                            **path** and **contents** key, to be injected
+                            into the rebuilt server at launch.
+                            *Default: None*
 
         :returns: The rebuilt :class:`~openstack.compute.v2.server.Server`
                   instance.
         """
         server = self._get_resource(_server.Server, server)
-        return server.rebuild(self.session, name, admin_password, **attrs)
+        return server.rebuild(self._session, name, admin_password, **attrs)
 
     def resize_server(self, server, flavor):
         """Resize a server
@@ -488,7 +502,7 @@ class Proxy(proxy2.BaseProxy):
         """
         server = self._get_resource(_server.Server, server)
         flavor_id = resource2.Resource._get_id(flavor)
-        server.resize(self.session, flavor_id)
+        server.resize(self._session, flavor_id)
 
     def confirm_server_resize(self, server):
         """Confirm a server resize
@@ -499,7 +513,7 @@ class Proxy(proxy2.BaseProxy):
         :returns: None
         """
         server = self._get_resource(_server.Server, server)
-        server.confirm_resize(self.session)
+        server.confirm_resize(self._session)
 
     def revert_server_resize(self, server):
         """Revert a server resize
@@ -510,7 +524,7 @@ class Proxy(proxy2.BaseProxy):
         :returns: None
         """
         server = self._get_resource(_server.Server, server)
-        server.revert_resize(self.session)
+        server.revert_resize(self._session)
 
     def create_server_image(self, server, name, metadata=None):
         """Create an image from a server
@@ -523,7 +537,7 @@ class Proxy(proxy2.BaseProxy):
         :returns: None
         """
         server = self._get_resource(_server.Server, server)
-        server.create_image(self.session, name, metadata)
+        server.create_image(self._session, name, metadata)
 
     def add_security_group_to_server(self, server, security_group):
         """Add a security group to a server
@@ -538,10 +552,10 @@ class Proxy(proxy2.BaseProxy):
         """
         server = self._get_resource(_server.Server, server)
         security_group_id = resource2.Resource._get_id(security_group)
-        server.add_security_group(self.session, security_group_id)
+        server.add_security_group(self._session, security_group_id)
 
     def remove_security_group_from_server(self, server, security_group):
-        """Add a security group to a server
+        """Remove a security group from a server
 
         :param server: Either the ID of a server or a
                        :class:`~openstack.compute.v2.server.Server` instance.
@@ -553,11 +567,217 @@ class Proxy(proxy2.BaseProxy):
         """
         server = self._get_resource(_server.Server, server)
         security_group_id = resource2.Resource._get_id(security_group)
-        server.remove_security_group(self.session, security_group_id)
+        server.remove_security_group(self._session, security_group_id)
+
+    def add_fixed_ip_to_server(self, server, network_id):
+        """Adds a fixed IP address to a server instance.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param network_id: The ID of the network from which a fixed IP address
+                           is about to be allocated.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.add_fixed_ip(self._session, network_id)
+
+    def remove_fixed_ip_from_server(self, server, address):
+        """Removes a fixed IP address from a server instance.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param address: The fixed IP address to be disassociated from the
+                        server.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.remove_fixed_ip(self._session, address)
+
+    def add_floating_ip_to_server(self, server, address, fixed_address=None):
+        """Adds a floating IP address to a server instance.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param address: The floating IP address to be added to the server.
+        :param fixed_address: The fixed IP address to be associated with the
+                              floating IP address. Used when the server is
+                              connected to multiple networks.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.add_floating_ip(self._session, address,
+                               fixed_address=fixed_address)
+
+    def remove_floating_ip_from_server(self, server, address):
+        """Removes a floating IP address from a server instance.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param address: The floating IP address to be disassociated from the
+                        server.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.remove_floating_ip(self._session, address)
+
+    def pause_server(self, server):
+        """Pauses a server and changes its status to ``PAUSED``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.pause(self._session)
+
+    def unpause_server(self, server):
+        """Unpauses a paused server and changes its status to ``ACTIVE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.unpause(self._session)
+
+    def suspend_server(self, server):
+        """Suspends a server and changes its status to ``SUSPENDED``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.suspend(self._session)
+
+    def resume_server(self, server):
+        """Resumes a suspended server and changes its status to ``ACTIVE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.resume(self._session)
+
+    def lock_server(self, server):
+        """Locks a server.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.lock(self._session)
+
+    def unlock_server(self, server):
+        """Unlocks a locked server.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.unlock(self._session)
+
+    def rescue_server(self, server, admin_pass=None, image_ref=None):
+        """Puts a server in rescue mode and changes it status to ``RESCUE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param admin_pass: The password for the rescued server. If you omit
+                           this parameter, the operation generates a new
+                           password.
+        :param image_ref: The image reference to use to rescue your server.
+                          This can be the image ID or its full URL. If you
+                          omit this parameter, the base image reference will
+                          be used.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.rescue(self._session, admin_pass=admin_pass,
+                      image_ref=image_ref)
+
+    def unrescue_server(self, server):
+        """Unrescues a server and changes its status to ``ACTIVE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.unrescue(self._session)
+
+    def evacuate_server(self, server, host=None, admin_pass=None, force=None):
+        """Evacuates a server from a failed host to a new host.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param host: An optional parameter specifying the name or ID of the
+                     host to which the server is evacuated.
+        :param admin_pass: An optional parameter specifying the administrative
+                           password to access the evacuated or rebuilt server.
+        :param force: Force an evacuation by not verifying the provided
+                      destination host by the scheduler. (New in API version
+                      2.29).
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.evacuate(self._session, host=host, admin_pass=admin_pass,
+                        force=force)
+
+    def start_server(self, server):
+        """Starts a stopped server and changes its state to ``ACTIVE``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.start(self._session)
+
+    def stop_server(self, server):
+        """Stops a running server and changes its state to ``SHUTOFF``.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.stop(self._session)
+
+    def shelve_server(self, server):
+        """Shelves a server.
+
+        All associated data and resources are kept but anything still in
+        memory is not retained. Policy defaults enable only users with
+        administrative role or the owner of the server to perform this
+        operation. Cloud provides could change this permission though.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.shelve(self._session)
+
+    def unshelve_server(self, server):
+        """Unselves or restores a shelved server.
+
+        Policy defaults enable only users with administrative role or the
+        owner of the server to perform this operation. Cloud provides could
+        change this permission though.
+
+        :param server: Either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :returns: None
+        """
+        server = self._get_resource(_server.Server, server)
+        server.unshelve(self._session)
 
     def wait_for_server(self, server, status='ACTIVE', failures=['ERROR'],
                         interval=2, wait=120):
-        return resource2.wait_for_status(self.session, server, status,
+        return resource2.wait_for_status(self._session, server, status,
                                          failures, interval, wait)
 
     def create_server_interface(self, server, **attrs):
@@ -666,8 +886,8 @@ class Proxy(proxy2.BaseProxy):
                              requires extra permission.
 
         :returns: A generator of availability zone
-        :rtype: :class:`~openstack.compute.v2.availability_zone.
-        AvailabilityZone`
+        :rtype: :class:`~openstack.compute.v2.availability_zone.\
+                        AvailabilityZone`
         """
         if details:
             az = availability_zone.AvailabilityZoneDetail
@@ -689,7 +909,7 @@ class Proxy(proxy2.BaseProxy):
         :rtype: :class:`~openstack.compute.v2.server.Server`
         """
         res = self._get_base_resource(server, _server.Server)
-        metadata = res.get_metadata(self.session)
+        metadata = res.get_metadata(self._session)
         result = _server.Server.existing(id=res.id, metadata=metadata)
         return result
 
@@ -710,7 +930,7 @@ class Proxy(proxy2.BaseProxy):
         :rtype: :class:`~openstack.compute.v2.server.Server`
         """
         res = self._get_base_resource(server, _server.Server)
-        metadata = res.set_metadata(self.session, **metadata)
+        metadata = res.set_metadata(self._session, **metadata)
         result = _server.Server.existing(id=res.id, metadata=metadata)
         return result
 
@@ -723,12 +943,12 @@ class Proxy(proxy2.BaseProxy):
                        :class:`~openstack.compute.v2.server.Server` or
                        :class:`~openstack.compute.v2.server.ServerDetail`
                        instance.
-        :param list keys: The keys to delete
+        :param keys: The keys to delete
 
         :rtype: ``None``
         """
         res = self._get_base_resource(server, _server.Server)
-        return res.delete_metadata(self.session, keys)
+        return res.delete_metadata(self._session, keys)
 
     def create_server_group(self, **attrs):
         """Create a new server group from attributes
@@ -861,7 +1081,7 @@ class Proxy(proxy2.BaseProxy):
         :returns: None
         """
         service = self._get_resource(_service.Service, service)
-        service.force_down(self.session, host, binary)
+        service.force_down(self._session, host, binary)
 
     def disable_service(self, service, host, binary, disabled_reason=None):
         """Disable a service
@@ -875,7 +1095,7 @@ class Proxy(proxy2.BaseProxy):
         :returns: None
         """
         service = self._get_resource(_service.Service, service)
-        service.disable(self.session,
+        service.disable(self._session,
                         host, binary,
                         disabled_reason)
 
@@ -891,7 +1111,7 @@ class Proxy(proxy2.BaseProxy):
         :returns: None
         """
         service = self._get_resource(_service.Service, service)
-        service.enable(self.session, host, binary)
+        service.enable(self._session, host, binary)
 
     def services(self):
         """Return a generator of service
@@ -901,3 +1121,126 @@ class Proxy(proxy2.BaseProxy):
         """
 
         return self._list(_service.Service, paginated=False)
+
+    def create_volume_attachment(self, server, **attrs):
+        """Create a new volume attachment from attributes
+
+        :param server: The server can be either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server` instance.
+        :param dict attrs: Keyword arguments which will be used to create a
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`,
+            comprised of the properties on the VolumeAttachment class.
+
+        :returns: The results of volume attachment creation
+        :rtype:
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+        """
+        server_id = resource2.Resource._get_id(server)
+        return self._create(_volume_attachment.VolumeAttachment,
+                            server_id=server_id, **attrs)
+
+    def update_volume_attachment(self, volume_attachment, server,
+                                 **attrs):
+        """update a volume attachment
+
+        :param volume_attachment:
+            The value can be either the ID of a volume attachment or a
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+            instance.
+        :param server: This parameter need to be specified when
+                       VolumeAttachment ID is given as value. It can be
+                       either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`
+                       instance that the attachment belongs to.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when the volume attachment does not exist.
+                    When set to ``True``, no exception will be set when
+                    attempting to delete a nonexistent volume  attachment.
+
+        :returns: ``None``
+        """
+        server_id = self._get_uri_attribute(volume_attachment, server,
+                                            "server_id")
+        volume_attachment = resource2.Resource._get_id(volume_attachment)
+
+        return self._update(_volume_attachment.VolumeAttachment,
+                            attachment_id=volume_attachment,
+                            server_id=server_id)
+
+    def delete_volume_attachment(self, volume_attachment, server,
+                                 ignore_missing=True):
+        """Delete a volume attachment
+
+        :param volume_attachment:
+            The value can be either the ID of a volume attachment or a
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+            instance.
+        :param server: This parameter need to be specified when
+                       VolumeAttachment ID is given as value. It can be either
+                       the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`
+                       instance that the attachment belongs to.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when the volume attachment does not exist.
+                    When set to ``True``, no exception will be set when
+                    attempting to delete a nonexistent volume attachment.
+
+        :returns: ``None``
+        """
+        server_id = self._get_uri_attribute(volume_attachment, server,
+                                            "server_id")
+        volume_attachment = resource2.Resource._get_id(volume_attachment)
+
+        self._delete(_volume_attachment.VolumeAttachment,
+                     attachment_id=volume_attachment,
+                     server_id=server_id,
+                     ignore_missing=ignore_missing)
+
+    def get_volume_attachment(self, volume_attachment, server,
+                              ignore_missing=True):
+        """Get a single volume attachment
+
+        :param volume_attachment:
+            The value can be the ID of a volume attachment or a
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+            instance.
+        :param server: This parameter need to be specified when
+                       VolumeAttachment ID is given as value. It can be either
+                       the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`
+                       instance that the attachment belongs to.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when the volume attachment does not exist.
+                    When set to ``True``, no exception will be set when
+                    attempting to delete a nonexistent volume attachment.
+
+        :returns: One
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        server_id = self._get_uri_attribute(volume_attachment, server,
+                                            "server_id")
+        volume_attachment = resource2.Resource._get_id(volume_attachment)
+
+        return self._get(_volume_attachment.VolumeAttachment,
+                         server_id=server_id,
+                         attachment_id=volume_attachment,
+                         ignore_missing=ignore_missing)
+
+    def volume_attachments(self, server):
+        """Return a generator of volume attachments
+
+        :param server: The server can be either the ID of a server or a
+                       :class:`~openstack.compute.v2.server.Server`.
+
+        :returns: A generator of VolumeAttachment objects
+        :rtype:
+            :class:`~openstack.compute.v2.volume_attachment.VolumeAttachment`
+        """
+        server_id = resource2.Resource._get_id(server)
+        return self._list(_volume_attachment.VolumeAttachment, paginated=False,
+                          server_id=server_id)
