@@ -11,10 +11,11 @@
 # under the License.
 
 from openstack.network import network_service
-from openstack import resource
+from openstack import resource2 as resource
 
 
 class AddressScope(resource.Resource):
+    """Address scope extension."""
     resource_key = 'address_scope'
     resources_key = 'address_scopes'
     base_path = '/address-scopes'
@@ -22,19 +23,25 @@ class AddressScope(resource.Resource):
 
     # capabilities
     allow_create = True
-    allow_retrieve = True
+    allow_get = True
     allow_update = True
     allow_delete = True
     allow_list = True
 
+    _query_mapping = resource.QueryParameters(
+        'name', 'ip_version',
+        project_id='tenant_id',
+        is_shared='shared',
+    )
+
     # Properties
     #: The address scope name.
-    name = resource.prop('name')
+    name = resource.Body('name')
     #: The ID of the project that owns the address scope.
-    project_id = resource.prop('tenant_id')
+    project_id = resource.Body('tenant_id')
     #: The IP address family of the address scope.
     #: *Type: int*
-    ip_version = resource.prop('ip_version', type=int)
+    ip_version = resource.Body('ip_version', type=int)
     #: Indicates whether this address scope is shared across all projects.
     #: *Type: bool*
-    is_shared = resource.prop('shared', type=bool)
+    is_shared = resource.Body('shared', type=bool)
