@@ -34,6 +34,7 @@ class Network(resource.Resource):
         ipv6_address_scope_id='ipv6_address_scope',
         is_admin_state_up='admin_state_up',
         is_port_security_enabled='port_security_enabled',
+        is_router_external='router:external',
         is_shared='shared',
         provider_network_type='provider:network_type',
         provider_physical_network='provider:physical_network',
@@ -108,6 +109,8 @@ class Network(resource.Resource):
     subnet_ids = resource.Body('subnets', type=list)
     #: Timestamp when the network was last updated.
     updated_at = resource.Body('updated_at')
+    #: Indicates the VLAN transparency mode of the network
+    is_vlan_transparent = resource.Body('vlan_transparent', type=bool)
 
 
 class DHCPAgentHostingNetwork(Network):
