@@ -10,6 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import deprecation
 import mock
 
 from openstack.cluster.v1 import _proxy
@@ -58,6 +59,10 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
     def test_profile_create(self):
         self.verify_create(self.proxy.create_profile, profile.Profile)
 
+    def test_profile_validate(self):
+        self.verify_create(self.proxy.validate_profile,
+                           profile.ProfileValidate)
+
     def test_profile_delete(self):
         self.verify_delete(self.proxy.delete_profile, profile.Profile, False)
 
@@ -103,6 +108,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
     def test_cluster_update(self):
         self.verify_update(self.proxy.update_cluster, cluster.Cluster)
 
+    @deprecation.fail_if_not_removed
     @mock.patch.object(proxy_base.BaseProxy, '_find')
     def test_cluster_add_nodes(self, mock_find):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
@@ -114,6 +120,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
         mock_find.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER",
                                           ignore_missing=False)
 
+    @deprecation.fail_if_not_removed
     def test_cluster_add_nodes_with_obj(self):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
         self._verify("openstack.cluster.v1.cluster.Cluster.add_nodes",
@@ -121,6 +128,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
                      method_args=[mock_cluster, ["node1"]],
                      expected_args=[["node1"]])
 
+    @deprecation.fail_if_not_removed
     @mock.patch.object(proxy_base.BaseProxy, '_find')
     def test_cluster_del_nodes(self, mock_find):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
@@ -132,13 +140,37 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
         mock_find.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER",
                                           ignore_missing=False)
 
+    @deprecation.fail_if_not_removed
     def test_cluster_del_nodes_with_obj(self):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
         self._verify("openstack.cluster.v1.cluster.Cluster.del_nodes",
                      self.proxy.cluster_del_nodes,
                      method_args=[mock_cluster, ["node1"]],
-                     expected_args=[["node1"]])
+                     method_kwargs={"key": "value"},
+                     expected_args=[["node1"]],
+                     expected_kwargs={"key": "value"})
 
+    @deprecation.fail_if_not_removed
+    @mock.patch.object(proxy_base.BaseProxy, '_find')
+    def test_cluster_replace_nodes(self, mock_find):
+        mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
+        mock_find.return_value = mock_cluster
+        self._verify("openstack.cluster.v1.cluster.Cluster.replace_nodes",
+                     self.proxy.cluster_replace_nodes,
+                     method_args=["FAKE_CLUSTER", {"node1": "node2"}],
+                     expected_args=[{"node1": "node2"}])
+        mock_find.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER",
+                                          ignore_missing=False)
+
+    @deprecation.fail_if_not_removed
+    def test_cluster_replace_nodes_with_obj(self):
+        mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
+        self._verify("openstack.cluster.v1.cluster.Cluster.replace_nodes",
+                     self.proxy.cluster_replace_nodes,
+                     method_args=[mock_cluster, {"node1": "node2"}],
+                     expected_args=[{"node1": "node2"}])
+
+    @deprecation.fail_if_not_removed
     @mock.patch.object(proxy_base.BaseProxy, '_find')
     def test_cluster_scale_out(self, mock_find):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
@@ -150,6 +182,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
         mock_find.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER",
                                           ignore_missing=False)
 
+    @deprecation.fail_if_not_removed
     def test_cluster_scale_out_with_obj(self):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
         self._verify("openstack.cluster.v1.cluster.Cluster.scale_out",
@@ -157,6 +190,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
                      method_args=[mock_cluster, 5],
                      expected_args=[5])
 
+    @deprecation.fail_if_not_removed
     @mock.patch.object(proxy_base.BaseProxy, '_find')
     def test_cluster_scale_in(self, mock_find):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
@@ -168,6 +202,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
         mock_find.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER",
                                           ignore_missing=False)
 
+    @deprecation.fail_if_not_removed
     def test_cluster_scale_in_with_obj(self):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
         self._verify("openstack.cluster.v1.cluster.Cluster.scale_in",
@@ -195,6 +230,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
                      method_kwargs={'k1': 'v1', 'k2': 'v2'},
                      expected_kwargs={'k1': 'v1', 'k2': 'v2'})
 
+    @deprecation.fail_if_not_removed
     @mock.patch.object(proxy_base.BaseProxy, '_find')
     def test_cluster_attach_policy(self, mock_find):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
@@ -208,6 +244,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
         mock_find.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER",
                                           ignore_missing=False)
 
+    @deprecation.fail_if_not_removed
     def test_cluster_attach_policy_with_obj(self):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
         self._verify("openstack.cluster.v1.cluster.Cluster.policy_attach",
@@ -217,6 +254,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
                      expected_args=["FAKE_POLICY"],
                      expected_kwargs={"k1": "v1", 'k2': "v2"})
 
+    @deprecation.fail_if_not_removed
     @mock.patch.object(proxy_base.BaseProxy, '_find')
     def test_cluster_detach_policy(self, mock_find):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
@@ -228,6 +266,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
         mock_find.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER",
                                           ignore_missing=False)
 
+    @deprecation.fail_if_not_removed
     def test_cluster_detach_policy_with_obj(self):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
         self._verify("openstack.cluster.v1.cluster.Cluster.policy_detach",
@@ -235,6 +274,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
                      method_args=[mock_cluster, "FAKE_POLICY"],
                      expected_args=["FAKE_POLICY"])
 
+    @deprecation.fail_if_not_removed
     @mock.patch.object(proxy_base.BaseProxy, '_find')
     def test_cluster_update_policy(self, mock_find):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
@@ -248,6 +288,7 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
         mock_find.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER",
                                           ignore_missing=False)
 
+    @deprecation.fail_if_not_removed
     def test_cluster_update_policy_with_obj(self):
         mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
         self._verify("openstack.cluster.v1.cluster.Cluster.policy_update",
@@ -282,6 +323,17 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
                      method_args=["FAKE_CLUSTER"])
         mock_get.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER")
 
+    @deprecation.fail_if_not_removed
+    @mock.patch.object(proxy_base.BaseProxy, '_get_resource')
+    def test_cluster_operation(self, mock_get):
+        mock_cluster = cluster.Cluster.new(id='FAKE_CLUSTER')
+        mock_get.return_value = mock_cluster
+        self._verify("openstack.cluster.v1.cluster.Cluster.op",
+                     self.proxy.cluster_operation,
+                     method_args=["FAKE_CLUSTER", "dance"],
+                     expected_args=["dance"])
+        mock_get.assert_called_once_with(cluster.Cluster, "FAKE_CLUSTER")
+
     def test_node_create(self):
         self.verify_create(self.proxy.create_node, node.Node)
 
@@ -333,9 +385,23 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
                      method_args=["FAKE_NODE"])
         mock_get.assert_called_once_with(node.Node, "FAKE_NODE")
 
+    @deprecation.fail_if_not_removed
+    @mock.patch.object(proxy_base.BaseProxy, '_get_resource')
+    def test_node_operation(self, mock_get):
+        mock_node = node.Node.new(id='FAKE_CLUSTER')
+        mock_get.return_value = mock_node
+        self._verify("openstack.cluster.v1.node.Node.op",
+                     self.proxy.node_operation,
+                     method_args=["FAKE_NODE", "dance"],
+                     expected_args=["dance"])
+        mock_get.assert_called_once_with(node.Node, "FAKE_NODE")
+
     def test_policy_create(self):
         self.verify_create(self.proxy.create_policy, policy.Policy)
 
+    def test_policy_validate(self):
+        self.verify_create(self.proxy.validate_policy, policy.PolicyValidate)
+
     def test_policy_delete(self):
         self.verify_delete(self.proxy.delete_policy, policy.Policy, False)
 
@@ -431,3 +497,41 @@ class TestClusterProxy(test_proxy_base2.TestProxyBase):
                          paginated=True,
                          method_kwargs={'limit': 2},
                          expected_kwargs={'limit': 2})
+
+    @mock.patch("openstack.resource2.wait_for_status")
+    def test_wait_for(self, mock_wait):
+        mock_resource = mock.Mock()
+        mock_wait.return_value = mock_resource
+
+        self.proxy.wait_for_status(mock_resource, 'ACTIVE')
+
+        mock_wait.assert_called_once_with(self.session, mock_resource,
+                                          'ACTIVE', [], 2, 120)
+
+    @mock.patch("openstack.resource2.wait_for_status")
+    def test_wait_for_params(self, mock_wait):
+        mock_resource = mock.Mock()
+        mock_wait.return_value = mock_resource
+
+        self.proxy.wait_for_status(mock_resource, 'ACTIVE', ['ERROR'], 1, 2)
+
+        mock_wait.assert_called_once_with(self.session, mock_resource,
+                                          'ACTIVE', ['ERROR'], 1, 2)
+
+    @mock.patch("openstack.resource2.wait_for_delete")
+    def test_wait_for_delete(self, mock_wait):
+        mock_resource = mock.Mock()
+        mock_wait.return_value = mock_resource
+
+        self.proxy.wait_for_delete(mock_resource)
+
+        mock_wait.assert_called_once_with(self.session, mock_resource, 2, 120)
+
+    @mock.patch("openstack.resource2.wait_for_delete")
+    def test_wait_for_delete_params(self, mock_wait):
+        mock_resource = mock.Mock()
+        mock_wait.return_value = mock_resource
+
+        self.proxy.wait_for_delete(mock_resource, 1, 2)
+
+        mock_wait.assert_called_once_with(self.session, mock_resource, 1, 2)
